@@ -1,4 +1,4 @@
-# $Id: /mirror/perl/Swarmage/trunk/lib/Swarmage/Component.pm 2425 2007-09-03T10:56:40.325353Z daisuke  $
+# $Id: /mirror/perl/Swarmage/trunk/lib/Swarmage/Component.pm 3749 2007-10-19T05:00:46.962903Z daisuke  $
 #
 # Copyright (c) 2007 Daisuke Maki <daisuke@endeworks.jp>
 # All rights reserved.
@@ -12,6 +12,12 @@ our @ISA = qw(Class::C3::Componentised Class::Accessor::Grouped);
 
 sub component_base_class { __PACKAGE__ }
 
+sub mk_accessors
+{
+    my $class = shift;
+    $class->mk_group_accessor(simple => @_);
+}
+
 sub mk_classaccessor
 {
     my $self = shift;
@@ -33,12 +39,21 @@ __END__
 
 Swarmage::Component - Swarmage Component Base Class
 
+=head1 DESCRIPTION
+
+This is base class for Swarmage components. It automatically enables
+Class::C3::Componentised and Class::Accessor::Grouped for you.
+
 =head1 METHODS
 
 =head2 new
 
 Base constructor. Does not initialization (XXX - Probably should be changed)
 
+=head2 mk_accessors
+
+Creates a new instance accessor
+
 =head2 mk_classaccessor
 
 Creates a new class accessor
